Coverage for PIL\_util.py: 0%

# Coverage for PIL\_util.py : 0%

## 18 statements 0 run 18 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 | import os, sys py3 = sys.version_info.major >= 3 if py3: def isStringType(t): return isinstance(t, str) def isPath(f): return isinstance(f, (bytes, str)) else: def isStringType(t): return isinstance(t, basestring) def isPath(f): return isinstance(f, basestring) # Checks if an object is a string, and that it points to a directory. def isDirectory(f): return isPath(f) and os.path.isdir(f) class deferred_error(object): def __init__(self, ex): self.ex = ex def __getattr__(self, elt): raise self.ex